=== modified file 'documentation/docs.sh'
--- documentation/docs.sh	2015-03-03 14:41:12 +0000
+++ documentation/docs.sh	2015-05-19 07:55:27 +0000
@@ -15,7 +15,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-DOC_PATH=$1
+QDOC_PATH=$1
+QHELPGEN_PATH=$2
+DOC_PATH=$3
 if [ ! $SRC -o ! $DOC_PATH ]; then
     echo "Error - SRC and DOC_PATH must be defined"
     exit 1
@@ -24,28 +26,28 @@
 mkdir -p $DOC_PATH
 
 # Offline docs for QtCreator
-qdoc $SRC/ubuntu-ui-toolkit-qtcreator.qdocconf 2> $DOC_PATH/qdoc.log
+$QDOC_PATH $SRC/ubuntu-ui-toolkit-qtcreator.qdocconf 2> $DOC_PATH/qdoc.log
 # FIXME: With Qt 5.2 this warning shows up, forcibly omit it from errors
 grep -v "error: HTML file already exists; overwriting" $DOC_PATH/qdoc.log | grep -v "qdoc: warning: No documentation for 'global'" > $DOC_PATH/qdoc.err
 cat $DOC_PATH/qdoc.err
 test ! -s $DOC_PATH/qdoc.err || exit 1
 echo docs: Offline done.
 
-qhelpgenerator -o "$DOC_PATH/ubuntuuserinterfacetoolkit.qch" "$DOC_PATH/offline/ubuntuuserinterfacetoolkit.qhp" | grep -v ' does not exist! Skipping it'
+$QHELPGEN_PATH -o "$DOC_PATH/ubuntuuserinterfacetoolkit.qch" "$DOC_PATH/offline/ubuntuuserinterfacetoolkit.qhp" | grep -v ' does not exist! Skipping it'
 echo docs: qch done: $DOC_PATH
 
 # Online docs. Run qdoc twice: the second run with indexes for cross-referencing
 # other APIs but discard errors because qdoc inherits all doc bugs otherwise
-qdoc $SRC/ubuntu-ui-toolkit-online.qdocconf 2> $DOC_PATH/qdoc.log
+$QDOC_PATH $SRC/ubuntu-ui-toolkit-online.qdocconf 2> $DOC_PATH/qdoc.log
 grep -v "error: HTML file already exists; overwriting" $DOC_PATH/qdoc.log | grep -v "qdoc: warning: No documentation for 'global'" > $DOC_PATH/qdoc.err
 cat $DOC_PATH/qdoc.err
 test ! -s $DOC_PATH/qdoc.err || exit 1
 echo docs: Online done.
 
-qdoc $SRC/ubuntu-ui-toolkit-online-indexes.qdocconf 2> /dev/null
+$QDOC_PATH $SRC/ubuntu-ui-toolkit-online-indexes.qdocconf 2> /dev/null
 echo docs: Cross-referenced done.
 
-sed -r -i 's@(</p>)<p/>@\1@g' $1/html/*.html
-sed -r -i 's@(<a class="(next|prev)Page" href=".+">)(.+)(</a>)@<li>\1\3\4</li>@g' $1/html/*.html
-sed -r -i 's@(href="qmlmodule-ubuntu-components0-ubuntu-components-0-1.html">Basic QML Types)@href="overview-ubuntu-sdk.html">Ubuntu User Interface Toolkit@g' $1/html/*.html
+sed -r -i 's@(</p>)<p/>@\1@g' $DOC_PATH/html/*.html
+sed -r -i 's@(<a class="(next|prev)Page" href=".+">)(.+)(</a>)@<li>\1\3\4</li>@g' $DOC_PATH/html/*.html
+sed -r -i 's@(href="qmlmodule-ubuntu-components0-ubuntu-components-0-1.html">Basic QML Types)@href="overview-ubuntu-sdk.html">Ubuntu User Interface Toolkit@g' $DOC_PATH/html/*.html
 echo docs: HTML fixes done.

=== renamed file 'documentation/documentation.pri' => 'documentation/documentation.pro'
--- documentation/documentation.pri	2014-11-25 20:00:13 +0000
+++ documentation/documentation.pro	2015-05-19 07:55:27 +0000
@@ -1,11 +1,32 @@
-install_docs.files = $$shadowed($$_PRO_FILE_PWD_)/documentation/html
+TEMPLATE=aux
+TARGET=documentation
+
+load(qt_functions)
+
+#find the path to qdoc and qhelpgenerator
+qtPrepareTool(QDOC, qdoc)
+qtPrepareTool(QHELPGENERATOR, qhelpgenerator)
+
+DOC_SRC = $$ROOT_SOURCE_DIR
+equals(QT_MAJOR_VERSION, 5):lessThan(QT_MINOR_VERSION, 2) {
+    DOC_SRC = $$ROOT_SOURCE_DIR/documentation
+}
+
+DOC_PATH=$$shadowed($$ROOT_SOURCE_DIR)/documentation
+generate_docs.commands = cd $$ROOT_SOURCE_DIR; SRC=$$ROOT_SOURCE_DIR/documentation BLD=$$ROOT_BUILD_DIR/documentation $$ROOT_SOURCE_DIR/documentation/docs.sh $$QDOC $$QHELPGENERATOR $$DOC_PATH
+
+install_docs.files = $$shadowed($$ROOT_SOURCE_DIR)/documentation/html
 install_docs.path = /usr/share/ubuntu-ui-toolkit/doc
+install_docs.CONFIG += no_check_exist directory no_build
 install_docs.depends = docs
 
-install_qch.files = $$shadowed($$_PRO_FILE_PWD_)/documentation/ubuntuuserinterfacetoolkit.qch
+install_qch.files = $$shadowed($$ROOT_SOURCE_DIR)/documentation/ubuntuuserinterfacetoolkit.qch
 install_qch.path = /usr/share/qt5/doc/qch/
+install_qch.CONFIG += no_check_exist no_build
 install_qch.depends = docs
 
 INSTALLS += install_qch install_docs
 
+OTHER_FILES += *.qdocconf \
+               docs.sh
 

=== modified file 'export_modules_dir.sh'
--- export_modules_dir.sh	2015-01-29 17:11:56 +0000
+++ export_modules_dir.sh	2015-05-19 07:55:27 +0000
@@ -16,9 +16,9 @@
 #
 
 . `dirname $0`/build_paths.inc
-export QML_IMPORT_PATH=$BUILD_DIR/modules
-export QML2_IMPORT_PATH=$BUILD_DIR/modules
-export UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/modules
-/sbin/initctl set-env --global QML_IMPORT_PATH=$BUILD_DIR/modules
-/sbin/initctl set-env --global QML2_IMPORT_PATH=$BUILD_DIR/modules
-/sbin/initctl set-env --global UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/modules
+export QML_IMPORT_PATH=$BUILD_DIR/qml
+export QML2_IMPORT_PATH=$BUILD_DIR/qml
+export UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global QML_IMPORT_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global QML2_IMPORT_PATH=$BUILD_DIR/qml
+/sbin/initctl set-env --global UBUNTU_UI_TOOLKIT_THEMES_PATH=$BUILD_DIR/qml

=== modified file 'features/ubuntu_enable_testing.prf'
--- features/ubuntu_enable_testing.prf	2015-05-18 09:58:35 +0000
+++ features/ubuntu_enable_testing.prf	2015-05-19 07:55:27 +0000
@@ -1,6 +1,6 @@
 instbase = $$ROOT_BUILD_DIR/qml
 
-force_independent:if(debug_and_release|build_all|!CONFIG(release, debug|release)) {
+force_independent: {
     # These bizarre rules copy the files to the build directory
 
     defineReplace(qmlModStripSrcDir) {

=== modified file 'tests/unit/add_makecheck.pri'
--- tests/unit/add_makecheck.pri	2015-03-12 14:13:58 +0000
+++ tests/unit/add_makecheck.pri	2015-05-19 07:55:27 +0000
@@ -4,5 +4,5 @@
 
 check.target = check
 check.commands += cd $$_PRO_FILE_PWD_;
-check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/modules/Ubuntu/Components:$${ROOT_BUILD_DIR}/modules/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/modules/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/modules/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
+check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/qml/Ubuntu/Components:$${ROOT_BUILD_DIR}/qml/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/qml/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/qml/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
 check.commands += '$${ROOT_SOURCE_DIR}/tests/unit/runtest.sh "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}" "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}" minimal';

=== modified file 'tests/unit/add_qmlmakecheck.pri'
--- tests/unit/add_qmlmakecheck.pri	2015-03-12 14:13:58 +0000
+++ tests/unit/add_qmlmakecheck.pri	2015-05-19 07:55:27 +0000
@@ -6,6 +6,6 @@
 check.commands = "set -e;"
 for(TEST, TESTS) {
   check.commands += cd $$_PRO_FILE_PWD_;
-  check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/modules/Ubuntu/Components:$${ROOT_BUILD_DIR}/modules/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/modules/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/modules/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
+  check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/qml/Ubuntu/Components:$${ROOT_BUILD_DIR}/qml/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/qml/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/qml/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
   check.commands += '$${ROOT_SOURCE_DIR}/tests/unit/runtest.sh "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}" "$${TEST}" minimal';
 }

=== modified file 'tests/unit_x11/add_makecheck.pri'
--- tests/unit_x11/add_makecheck.pri	2015-03-12 14:13:58 +0000
+++ tests/unit_x11/add_makecheck.pri	2015-05-19 07:55:27 +0000
@@ -6,6 +6,6 @@
 !contains(QMAKE_HOST.arch,armv7l) {
     check.target = check
     check.commands += cd $$_PRO_FILE_PWD_;
-    check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/modules/Ubuntu/Components:$${ROOT_BUILD_DIR}/modules/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/modules/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/modules/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
+    check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/qml/Ubuntu/Components:$${ROOT_BUILD_DIR}/qml/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/qml/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/qml/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
     check.commands += '$${ROOT_SOURCE_DIR}/tests/unit/runtest.sh "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}" "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}"';
 }

=== modified file 'tests/unit_x11/add_qmlmakecheck.pri'
--- tests/unit_x11/add_qmlmakecheck.pri	2015-03-12 14:13:58 +0000
+++ tests/unit_x11/add_qmlmakecheck.pri	2015-05-19 07:55:27 +0000
@@ -9,7 +9,7 @@
  check.commands = "set -e;"
  for(TEST, TESTS) {
   check.commands += cd $$_PRO_FILE_PWD_;
-  check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/modules/Ubuntu/Components:$${ROOT_BUILD_DIR}/modules/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/modules/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/modules/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
+  check.commands += env LD_LIBRARY_PATH=$${ROOT_BUILD_DIR}/qml/Ubuntu/Components:$${ROOT_BUILD_DIR}/qml/Ubuntu/Layouts:$${ROOT_BUILD_DIR}/qml/Ubuntu/PerformanceMetrics:$${ROOT_BUILD_DIR}/qml/Ubuntu/Test UITK_TEST_KEEP_RUNNING=1
   check.commands += '$${ROOT_SOURCE_DIR}/tests/unit/runtest.sh "$$shadowed($$_PRO_FILE_PWD_)/$${TARGET}" "$${TEST}"';
  }
 }

=== modified file 'tests/unit_x11/tst_animator/tst_animator.qml'
--- tests/unit_x11/tst_animator/tst_animator.qml	2015-03-03 13:20:06 +0000
+++ tests/unit_x11/tst_animator/tst_animator.qml	2015-05-19 07:55:27 +0000
@@ -49,7 +49,7 @@
                 fillMode: Image.PreserveAspectFit
                 horizontalAlignment: Image.AlignHCenter
                 verticalAlignment: Image.AlignVCenter
-                source: "../../../modules/Ubuntu/Components/Themes/Ambiance/artwork/spinner@8.png"
+                source: "../../../src/Ubuntu/Components/Themes/Ambiance/artwork/spinner@8.png"
 
 
                 RotationAnimator on rotation {

=== modified file 'ubuntu-sdk.pro'
--- ubuntu-sdk.pro	2015-05-18 09:53:55 +0000
+++ ubuntu-sdk.pro	2015-05-19 07:55:27 +0000
@@ -1,51 +1,30 @@
 #include( documentation/documentation.pri )
 
-#TEMPLATE = subdirs
-#SUBDIRS += modules/ubuntu-ui-toolkit.pro tests examples po
-
 BUILD_PATH_CONTENTS="SRC_DIR=\"$$PWD\"" \
                     "BUILD_DIR=\"$$OUT_PWD\""
 
 write_file($$PWD/build_paths.inc,BUILD_PATH_CONTENTS)
 
 requires(qtHaveModule(quick))
-
-QMAKE_DOCS += documentation/ubuntu-ui-toolkit-online.qdocconf \
-              documentation/ubuntu-ui-toolkit-offline.qdocconf \
-              documentation/ubuntu-ui-toolkit-online-indexes.qdocconf \
-              documentation/ubuntu-ui-toolkit-common.qdocconf \
-              documentation/ubuntu-appdev-site-header.qdocconf \
-              documentation/ubuntu-appdev-site-footer.qdocconf \
-              documentation/ubuntu-ui-toolkit-qtcreator.qdocconf
-
 load(qt_parts)
 
+SUBDIRS += po documentation
 
-#tests.depends = sub-modules-ubuntu-ui-toolkit-pro
-#examples.depends = sub-modules-ubuntu-ui-toolkit-pro
+#when standalone we always want tests to be built
+force_independent: sub_tests.CONFIG -= no_default_target
 
 # additional 'make test' target required by continuous integration system
 test.target = test
 test.commands = make check
-test.depends = license sub-src
+test.depends = license sub_src
 QMAKE_EXTRA_TARGETS += test
 
 license.target = license
 license.commands = cd $$PWD; $$PWD/tests/license/checklicense.sh
 QMAKE_EXTRA_TARGETS += license
 
-#check.target = check
-#check.commands = $$PWD/tests/checkresults.sh $$PWD/tests/test_tst_*.xml
-
-#DOC_SRC = $$PWD
-#equals(QT_MAJOR_VERSION, 5):lessThan(QT_MINOR_VERSION, 2) {
-#    DOC_SRC = $$PWD/documentation
-#}
-
-#DOC_PATH=$$shadowed($$_PRO_FILE_PWD_)/documentation
-#docs.target = docs
-#docs.commands = cd $$PWD; SRC=$$PWD/documentation BLD=$$ROOT_BUILD_DIR/documentation $$PWD/documentation/docs.sh $$DOC_PATH
-#QMAKE_EXTRA_TARGETS += docs
+check.target = check
+check.commands = $$PWD/tests/checkresults.sh $$PWD/tests/test_tst_*.xml
 
 #helper files
 OTHER_FILES += \

